@@ -2,5 +2,5 @@
 # Copyright 2022 Canonical Ltd.
 # See LICENSE file for licensing details.
 
-from .charmlib import CharmLibManager
-from .pip import PipManager
+from .charmlib import Charmlib
+from .pip import Pip
